@@ -47,11 +47,7 @@ func TestStringInputModel(t *testing.T) {
 		},
 	} {
 		t.Run(tc.name, func(t *testing.T) {
-			actualModel := testRunModelWithInput(
-				t,
-				NewStringInputModel("prompt", tc.defaultValue),
-				tc.input,
-			)
+			actualModel := testRunModelWithInput(t, NewStringInputModel("prompt", tc.defaultValue), tc.input)
 			assert.Equal(t, tc.expectedCanceled, actualModel.Canceled())
 			assert.Equal(t, tc.expectedValue, actualModel.Value())
 		})
