@@ -181,6 +181,7 @@ type Config struct {
 	refreshExternals chezmoi.RefreshExternals
 	sourcePath       bool
 	templateFuncs    template.FuncMap
+	useBuiltinDiff   bool
 
 	// Password manager data.
 	gitHub  gitHubData
@@ -303,11 +304,19 @@ var (
 	}
 
 	whitespaceRx = regexp.MustCompile(`\s+`)
+
+	commonFlagCompletionFuncs = map[string]func(*cobra.Command, []string, string) ([]string, cobra.ShellCompDirective){
+		"exclude":    chezmoi.EntryTypeSetFlagCompletionFunc,
+		"format":     writeDataFormatFlagCompletionFunc,
+		"include":    chezmoi.EntryTypeSetFlagCompletionFunc,
+		"path-style": chezmoi.PathStyleFlagCompletionFunc,
+		"secrets":    severityFlagCompletionFunc,
+	}
 )
 
 // newConfig creates a new Config with the given options.
 func newConfig(options ...configOption) (*Config, error) {
-	userHomeDir, err := os.UserHomeDir()
+	userHomeDir, err := chezmoi.UserHomeDir()
 	if err != nil {
 		return nil, err
 	}
@@ -370,10 +379,6 @@ func newConfig(options ...configOption) (*Config, error) {
 		unmanaged: unmanagedCmdConfig{
 			pathStyle: chezmoi.PathStyleRelative,
 		},
-		upgrade: upgradeCmdConfig{
-			owner: gitHubOwner,
-			repo:  gitHubRepo,
-		},
 
 		// Configuration.
 		fileSystem: vfs.OSFS,
@@ -626,9 +631,8 @@ func (c *Config) applyArgs(
 			return err
 		}
 	default:
-		targetRelPaths, err = c.targetRelPaths(sourceState, args, targetRelPathsOptions{
-			mustBeManaged: true,
-			recursive:     options.recursive,
+		targetRelPaths, err = c.targetRelPaths(sourceState, args, &targetRelPathsOptions{
+			recursive: options.recursive,
 		})
 		if err != nil {
 			return err
@@ -1579,6 +1583,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 	persistentFlags.VarP(&c.refreshExternals, "refresh-externals", "R", "Refresh external cache")
 	persistentFlags.Lookup("refresh-externals").NoOptDefVal = chezmoi.RefreshExternalsAlways.String()
 	persistentFlags.BoolVar(&c.sourcePath, "source-path", c.sourcePath, "Specify targets by source path")
+	persistentFlags.BoolVarP(&c.useBuiltinDiff, "use-builtin-diff", "", c.useBuiltinDiff, "Use builtin diff")
 
 	if err := chezmoierrors.Combine(
 		rootCmd.MarkPersistentFlagFilename("config"),
@@ -1647,6 +1652,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 		cobracompletefig.CreateCompletionSpecCommand(),
 	} {
 		if cmd != nil {
+			registerCommonFlagCompletionFuncs(cmd)
 			rootCmd.AddCommand(cmd)
 		}
 	}
@@ -1657,7 +1663,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 // newDiffSystem returns a system that logs all changes to s to w using
 // diff.command if set or the builtin git diff otherwise.
 func (c *Config) newDiffSystem(s chezmoi.System, w io.Writer, dirAbsPath chezmoi.AbsPath) chezmoi.System {
-	if c.Diff.useBuiltinDiff || c.Diff.Command == "" {
+	if c.useBuiltinDiff || c.Diff.Command == "" {
 		options := &chezmoi.GitDiffSystemOptions{
 			Color:          c.Color.Value(c.colorAutoFunc),
 			Filter:         chezmoi.NewEntryTypeFilter(c.Diff.include.Bits(), c.Diff.Exclude.Bits()),
@@ -2326,7 +2332,10 @@ func (c *Config) run(dir chezmoi.AbsPath, name string, args []string) error {
 	cmd.Stdin = c.stdin
 	cmd.Stdout = c.stdout
 	cmd.Stderr = c.stderr
-	return c.baseSystem.RunCmd(cmd)
+	if err := chezmoilog.LogCmdRun(c.logger, cmd); err != nil {
+		return fmt.Errorf("%s: %w", name, err)
+	}
+	return nil
 }
 
 // runEditor runs the configured editor with args.
@@ -2427,9 +2436,8 @@ func (c *Config) setEnvironmentVariables() error {
 // sourceAbsPaths returns the source absolute paths for each target path in
 // args.
 func (c *Config) sourceAbsPaths(sourceState *chezmoi.SourceState, args []string) ([]chezmoi.AbsPath, error) {
-	targetRelPaths, err := c.targetRelPaths(sourceState, args, targetRelPathsOptions{
+	targetRelPaths, err := c.targetRelPaths(sourceState, args, &targetRelPathsOptions{
 		mustBeInSourceState: true,
-		mustBeManaged:       true,
 	})
 	if err != nil {
 		return nil, err
@@ -2452,7 +2460,6 @@ func (c *Config) targetRelPath(absPath chezmoi.AbsPath) (chezmoi.RelPath, error)
 
 type targetRelPathsOptions struct {
 	mustBeInSourceState bool
-	mustBeManaged       bool
 	recursive           bool
 }
 
@@ -2461,7 +2468,7 @@ type targetRelPathsOptions struct {
 func (c *Config) targetRelPaths(
 	sourceState *chezmoi.SourceState,
 	args []string,
-	options targetRelPathsOptions,
+	options *targetRelPathsOptions,
 ) (chezmoi.RelPaths, error) {
 	targetRelPaths := make(chezmoi.RelPaths, 0, len(args))
 	for _, arg := range args {
@@ -2474,16 +2481,16 @@ func (c *Config) targetRelPaths(
 			return nil, err
 		}
 		sourceStateEntry := sourceState.Get(targetRelPath)
-		if options.mustBeManaged && sourceStateEntry == nil {
+		if sourceStateEntry == nil {
 			return nil, fmt.Errorf("%s: not managed", arg)
 		}
-		if options.mustBeInSourceState {
+		if options != nil && options.mustBeInSourceState {
 			if _, ok := sourceStateEntry.(*chezmoi.SourceStateRemove); ok {
 				return nil, fmt.Errorf("%s: not in source state", arg)
 			}
 		}
 		targetRelPaths = append(targetRelPaths, targetRelPath)
-		if options.recursive {
+		if options != nil && options.recursive {
 			parentRelPath := targetRelPath
 			// FIXME we should not call s.TargetRelPaths() here - risk of
 			// accidentally quadratic
@@ -2642,6 +2649,7 @@ func newConfigFile(bds *xdg.BaseDirectorySpecification) ConfigFile {
 			auto: true,
 		},
 		Interpreters: defaultInterpreters,
+		Mode:         chezmoi.ModeFile,
 		Pager:        os.Getenv("PAGER"),
 		Progress: autoBool{
 			auto: true,
@@ -2700,6 +2708,7 @@ func newConfigFile(bds *xdg.BaseDirectorySpecification) ConfigFile {
 		Onepassword: onepasswordConfig{
 			Command: "op",
 			Prompt:  true,
+			Mode:    onepasswordModeAccount,
 		},
 		Pass: passConfig{
 			Command: "pass",
@@ -2767,8 +2776,15 @@ func newConfigFile(bds *xdg.BaseDirectorySpecification) ConfigFile {
 }
 
 func (f *ConfigFile) toMap() map[string]any {
+	// Make a copy of f and replace any default sentinels with the empty string
+	// to ensure that there are no default sentinels in the result.
+	configFile := *f
+	if configFile.Diff.Pager == defaultSentinel {
+		configFile.Diff.Pager = ""
+	}
+
 	var result map[string]any
-	if err := mapstructure.Decode(f, &result); err != nil {
+	if err := mapstructure.Decode(configFile, &result); err != nil {
 		panic(err)
 	}
 	return result
@@ -2802,6 +2818,21 @@ func parseCommand(command string, args []string) (string, []string, error) {
 	return command, args, nil
 }
 
+// registerCommonFlagCompletionFuncs registers completion functions for cmd's
+// common flags, recursively. It panics on any error.
+func registerCommonFlagCompletionFuncs(cmd *cobra.Command) {
+	cmd.Flags().VisitAll(func(flag *pflag.Flag) {
+		if flagCompletionFunc, ok := commonFlagCompletionFuncs[flag.Name]; ok {
+			if err := cmd.RegisterFlagCompletionFunc(flag.Name, flagCompletionFunc); err != nil {
+				panic(err)
+			}
+		}
+	})
+	for _, command := range cmd.Commands() {
+		registerCommonFlagCompletionFuncs(command)
+	}
+}
+
 // withVersionInfo sets the version information.
 func withVersionInfo(versionInfo VersionInfo) configOption {
 	return func(c *Config) error {
