@@ -16,7 +16,6 @@ type diffCmdConfig struct {
 	include        *chezmoi.EntryTypeSet
 	init           bool
 	recursive      bool
-	useBuiltinDiff bool
 }
 
 func (c *Config) newDiffCmd() *cobra.Command {
@@ -35,17 +34,13 @@ func (c *Config) newDiffCmd() *cobra.Command {
 		),
 	}
 
-	flags := diffCmd.Flags()
-	flags.VarP(c.Diff.Exclude, "exclude", "x", "Exclude entry types")
-	flags.VarP(c.Diff.include, "include", "i", "Include entry types")
-	flags.BoolVar(&c.Diff.init, "init", c.Diff.init, "Recreate config file from template")
-	flags.StringVar(&c.Diff.Pager, "pager", c.Diff.Pager, "Set pager")
-	flags.BoolVarP(&c.Diff.recursive, "recursive", "r", c.Diff.recursive, "Recurse into subdirectories")
-	flags.BoolVar(&c.Diff.Reverse, "reverse", c.Diff.Reverse, "Reverse the direction of the diff")
-	flags.BoolVar(&c.Diff.ScriptContents, "script-contents", c.Diff.ScriptContents, "Show script contents")
-	flags.BoolVarP(&c.Diff.useBuiltinDiff, "use-builtin-diff", "", c.Diff.useBuiltinDiff, "Use the builtin diff")
-
-	registerExcludeIncludeFlagCompletionFuncs(diffCmd)
+	diffCmd.Flags().VarP(c.Diff.Exclude, "exclude", "x", "Exclude entry types")
+	diffCmd.Flags().VarP(c.Diff.include, "include", "i", "Include entry types")
+	diffCmd.Flags().BoolVar(&c.Diff.init, "init", c.Diff.init, "Recreate config file from template")
+	diffCmd.Flags().StringVar(&c.Diff.Pager, "pager", c.Diff.Pager, "Set pager")
+	diffCmd.Flags().BoolVarP(&c.Diff.recursive, "recursive", "r", c.Diff.recursive, "Recurse into subdirectories")
+	diffCmd.Flags().BoolVar(&c.Diff.Reverse, "reverse", c.Diff.Reverse, "Reverse the direction of the diff")
+	diffCmd.Flags().BoolVar(&c.Diff.ScriptContents, "script-contents", c.Diff.ScriptContents, "Show script contents")
 
 	return diffCmd
 }
