@@ -101,21 +101,21 @@ func (c *Config) newInitCmd() *cobra.Command {
 		),
 	}
 
-	flags := initCmd.Flags()
-	c.addInteractiveTemplateFuncFlags(flags)
-	flags.BoolVarP(&c.init.apply, "apply", "a", c.init.apply, "Update destination directory")
-	flags.StringVar(&c.init.branch, "branch", c.init.branch, "Set initial branch to checkout")
-	flags.VarP(&c.init.configPath, "config-path", "C", "Path to write generated config file")
-	flags.BoolVar(&c.init.data, "data", c.init.data, "Include existing template data")
-	flags.IntVarP(&c.init.depth, "depth", "d", c.init.depth, "Create a shallow clone")
-	flags.VarP(c.init.filter.Exclude, "exclude", "x", "Exclude entry types")
-	flags.BoolVarP(&c.init.guessRepoURL, "guess-repo-url", "g", c.init.guessRepoURL, "Guess the repo URL")
-	flags.VarP(c.init.filter.Include, "include", "i", "Include entry types")
-	flags.BoolVar(&c.init.oneShot, "one-shot", c.init.oneShot, "Run in one-shot mode")
-	flags.BoolVarP(&c.init.purge, "purge", "p", c.init.purge, "Purge config and source directories after running")
-	flags.BoolVarP(&c.init.purgeBinary, "purge-binary", "P", c.init.purgeBinary, "Purge chezmoi binary after running")
-	flags.BoolVar(&c.init.recurseSubmodules, "recurse-submodules", c.init.recurseSubmodules, "Checkout submodules recursively")
-	flags.BoolVar(&c.init.ssh, "ssh", c.init.ssh, "Use ssh instead of https when guessing repo URL")
+	c.addInteractiveTemplateFuncFlags(initCmd.Flags())
+	initCmd.Flags().BoolVarP(&c.init.apply, "apply", "a", c.init.apply, "Update destination directory")
+	initCmd.Flags().StringVar(&c.init.branch, "branch", c.init.branch, "Set initial branch to checkout")
+	initCmd.Flags().VarP(&c.init.configPath, "config-path", "C", "Path to write generated config file")
+	initCmd.Flags().BoolVar(&c.init.data, "data", c.init.data, "Include existing template data")
+	initCmd.Flags().IntVarP(&c.init.depth, "depth", "d", c.init.depth, "Create a shallow clone")
+	initCmd.Flags().VarP(c.init.filter.Exclude, "exclude", "x", "Exclude entry types")
+	initCmd.Flags().BoolVarP(&c.init.guessRepoURL, "guess-repo-url", "g", c.init.guessRepoURL, "Guess the repo URL")
+	initCmd.Flags().VarP(c.init.filter.Include, "include", "i", "Include entry types")
+	initCmd.Flags().BoolVar(&c.init.oneShot, "one-shot", c.init.oneShot, "Run in one-shot mode")
+	initCmd.Flags().BoolVarP(&c.init.purge, "purge", "p", c.init.purge, "Purge config and source directories after running")
+	initCmd.Flags().BoolVarP(&c.init.purgeBinary, "purge-binary", "P", c.init.purgeBinary, "Purge chezmoi binary after running")
+	initCmd.Flags().
+		BoolVar(&c.init.recurseSubmodules, "recurse-submodules", c.init.recurseSubmodules, "Checkout submodules recursively")
+	initCmd.Flags().BoolVar(&c.init.ssh, "ssh", c.init.ssh, "Use ssh instead of https when guessing repo URL")
 
 	return initCmd
 }
