@@ -32,12 +32,9 @@ func (c *Config) newReAddCmd() *cobra.Command {
 		),
 	}
 
-	flags := reAddCmd.Flags()
-	flags.VarP(c.reAdd.filter.Exclude, "exclude", "x", "Exclude entry types")
-	flags.VarP(c.reAdd.filter.Include, "include", "i", "Include entry types")
-	flags.BoolVarP(&c.reAdd.recursive, "recursive", "r", c.reAdd.recursive, "Recurse into subdirectories")
-
-	registerExcludeIncludeFlagCompletionFuncs(reAddCmd)
+	reAddCmd.Flags().VarP(c.reAdd.filter.Exclude, "exclude", "x", "Exclude entry types")
+	reAddCmd.Flags().VarP(c.reAdd.filter.Include, "include", "i", "Include entry types")
+	reAddCmd.Flags().BoolVarP(&c.reAdd.recursive, "recursive", "r", c.reAdd.recursive, "Recurse into subdirectories")
 
 	return reAddCmd
 }
@@ -55,9 +52,8 @@ func (c *Config) runReAddCmd(cmd *cobra.Command, args []string, sourceState *che
 		)
 	} else {
 		var err error
-		targetRelPaths, err = c.targetRelPaths(sourceState, args, targetRelPathsOptions{
-			mustBeManaged: true,
-			recursive:     c.reAdd.recursive,
+		targetRelPaths, err = c.targetRelPaths(sourceState, args, &targetRelPathsOptions{
+			recursive: c.reAdd.recursive,
 		})
 		if err != nil {
 			return err
