@@ -12,6 +12,7 @@ import (
 	"path/filepath"
 	"regexp"
 	"runtime"
+	"slices"
 	"strconv"
 	"strings"
 
@@ -276,7 +277,7 @@ func (c *Config) includeTemplateTemplateFunc(filename string, args ...any) strin
 	}
 
 	templateOptions := chezmoi.TemplateOptions{
-		Options: append([]string(nil), c.Template.Options...),
+		Options: slices.Clone(c.Template.Options),
 	}
 	tmpl, err := chezmoi.ParseTemplate(filename, contents, c.templateFuncs, templateOptions)
 	if err != nil {
@@ -303,7 +304,7 @@ func (c *Config) ioregTemplateFunc() map[string]any {
 	args := []string{"-a", "-l"}
 	cmd := exec.Command(command, args...)
 	cmd.Stderr = os.Stderr
-	output, err := chezmoilog.LogCmdOutput(cmd)
+	output, err := chezmoilog.LogCmdOutput(c.logger, cmd)
 	if err != nil {
 		panic(newCmdOutputError(cmd, output, err))
 	}
@@ -390,7 +391,7 @@ func (c *Config) mozillaInstallHashTemplateFunc(path string) string {
 func (c *Config) outputTemplateFunc(name string, args ...string) string {
 	cmd := exec.Command(name, args...)
 	cmd.Stderr = os.Stderr
-	output, err := chezmoilog.LogCmdOutput(cmd)
+	output, err := chezmoilog.LogCmdOutput(c.logger, cmd)
 	if err != nil {
 		panic(newCmdOutputError(cmd, output, err))
 	}
