@@ -27,12 +27,7 @@ func (c *Config) newUnmanagedCmd() *cobra.Command {
 		Annotations: newAnnotations(),
 	}
 
-	flags := unmanagedCmd.Flags()
-	flags.VarP(&c.unmanaged.pathStyle, "path-style", "p", "Path style")
-
-	if err := unmanagedCmd.RegisterFlagCompletionFunc("path-style", chezmoi.PathStyleFlagCompletionFunc); err != nil {
-		panic(err)
-	}
+	unmanagedCmd.Flags().VarP(&c.unmanaged.pathStyle, "path-style", "p", "Path style")
 
 	return unmanagedCmd
 }
@@ -59,6 +54,10 @@ func (c *Config) runUnmanagedCmd(cmd *cobra.Command, args []string, sourceState
 	unmanagedRelPaths := make(map[chezmoi.RelPath]struct{})
 	walkFunc := func(destAbsPath chezmoi.AbsPath, fileInfo fs.FileInfo, err error) error {
 		if err != nil {
+			if c.keepGoing {
+				c.errorf("%s: %v", destAbsPath, err)
+				return nil
+			}
 			return err
 		}
 		if destAbsPath == c.DestDirAbsPath {
