@@ -2,7 +2,6 @@ package cmd
 
 import (
 	"fmt"
-	"io/fs"
 	"strings"
 
 	"golang.org/x/sys/windows/registry"
@@ -35,10 +34,6 @@ var defaultInterpreters = map[string]*chezmoi.Interpreter{
 	},
 }
 
-func fileInfoUID(fs.FileInfo) int {
-	return 0
-}
-
 func windowsVersion() (map[string]any, error) {
 	registryKey, err := registry.OpenKey(
 		registry.LOCAL_MACHINE,
